import low from 'lowdb';
import { pluginUtils, searchUtils } from '@verdaccio/core';
import { Config, Logger, Token, TokenFilter } from '@verdaccio/types';
import { LocalStorage } from './pkg-utils';
export declare const ERROR_DB_LOCKED = "Database is locked, please check error message printed during startup to prevent data loss";
type Storage = pluginUtils.Storage<{}>;
declare class LocalDatabase extends pluginUtils.Plugin<{}> implements Storage {
    private readonly path;
    private readonly logger;
    readonly config: Config;
    readonly storages: Map<string, string>;
    data: LocalStorage | undefined;
    locked: boolean;
    tokenDb: low.LowdbAsync<any> | null;
    constructor(config: Config, logger: Logger);
    init(): Promise<void>;
    getSecret(): Promise<string>;
    setSecret(secret: string): Promise<void>;
    add(name: string): Promise<void>;
    /**
     * The field storage could be absolute or relative.
     * If relative, it will be resolved against the config path.
     * If absolute, it will be returned as is.
     **/
    private getStoragePath;
    private getBaseConfigPath;
    /**
     * Filter and only match those values that the query define.
     **/
    filterByQuery(results: searchUtils.SearchItemPkg[], query: searchUtils.SearchQuery): Promise<searchUtils.SearchItemPkg[]>;
    getScore(_pkg: searchUtils.SearchItemPkg): Promise<searchUtils.Score>;
    /**
     *
     * @param query
     * @returns
     */
    search(query: searchUtils.SearchQuery): Promise<searchUtils.SearchItem[]>;
    remove(name: string): Promise<void>;
    get(): Promise<any>;
    getPackageStorage(packageName: string): pluginUtils.StorageHandler;
    clean(): Promise<void>;
    private _getCustomPackageLocalStorages;
    private _sync;
    private _getLocalStoragePath;
    private fetchLocalPackages;
    private getTokenDb;
    saveToken(token: Token): Promise<void>;
    deleteToken(user: string, tokenKey: string): Promise<void>;
    readTokens(filter: TokenFilter): Promise<Token[]>;
}
export default LocalDatabase;
