"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadPrivatePackages = loadPrivatePackages;
var _lodash = _interopRequireDefault(require("lodash"));
var _fs = require("./fs");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
async function loadPrivatePackages(path, logger) {
  const list = [];
  const emptyDatabase = {
    list,
    secret: ''
  };
  const data = await (0, _fs.readFilePromise)(path);
  if (_lodash.default.isNil(data)) {
    // readFilePromise is platform specific, FreeBSD might return null
    return emptyDatabase;
  }
  let db;
  try {
    db = JSON.parse(data);
  } catch (err) {
    logger.error({
      err,
      path
    }, `Package database file corrupted (invalid JSON) @{err.message}, please check the error printed below.File Path: @{path}`);
    throw Error('Package database file corrupted (invalid JSON)');
  }
  if (_lodash.default.isEmpty(db)) {
    return emptyDatabase;
  }
  return db;
}
//# sourceMappingURL=pkg-utils.js.map